Description
==============

Launcher menu wrapper.

Provides an API for launcher menus such as:

- [dmenu](https://tools.suckless.org/dmenu/)
- [bemenu](https://github.com/Cloudef/bemenu)

Can be extended to other menus: see section `configuration`


Documentation
=============

[![Documentation Status](https://readthedocs.org/projects/launcher-menus/badge/?version=latest)](https://launcher-menus.readthedocs.io/?badge=latest)

Source Code
===========

[![source](https://github.githubassets.com/favicons/favicon.png)](https://github.com/pradyparanjpe/launcher-menus.git)
[Repository](https://github.com/pradyparanjpe/launcher-menus.git)


What does it do
---------------

-   Runs a subprocess for the selected ``<menu>`` and returns its standard
    output or ``None``

